function [centroids,properties] = characterize(image_o)
    % Find object properties
    [clust,numb] = bwlabel(image_o, 8);
    s = regionprops(clust, {'Centroid'});
    measurements = regionprops(clust,'MajorAxisLength','MinorAxisLength');
    theta = regionprops(clust,'orientation'); % Angle between x-axis and major axis of the ellipse
    area = regionprops(clust,'Area');
    perimeter = regionprops(clust,'Perimeter');

    % Store centroids in matrix
    centroids = zeros(numb,2);
    for n=1:numb
        centroids(n,1)=s(n).Centroid(1);
        centroids(n,2)=s(n).Centroid(2);
    end

    % Store other properties in matrix (Order: area, majoraxis, minoraxis,
    % orientation, perimeter)
    properties = zeros(numb, 6);
    for m=1:numb
        properties(m,1)=area(m).Area;
        properties(m,2)=measurements(m).MajorAxisLength;
        properties(m,3)=measurements(m).MinorAxisLength;
        properties(m,4)=theta(m).Orientation;
        properties(m,5)=perimeter(m).Perimeter;
    end
end